"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initServer = void 0;
const interface_1 = require("../model/interface");
const browser_1 = require("./browser");
const webpack_1 = require("../inject/webpack");
const callback_on_layes_1 = require("./layes/callback-on.layes");
const enum_1 = require("../model/enum");
const help_1 = require("../help");
const check_up_to_date_1 = require("./check-up-to-date");
const ev = new callback_on_layes_1.CallbackOnStatus();
/**
 * Start the bot
 */
async function initServer(options) {
    return new Promise(async (resolve) => {
        resolve(ev);
        const mergeOptionsDefault = Object.assign(Object.assign({}, interface_1.defaultConfig), options);
        if (!!(options === null || options === void 0 ? void 0 : options.puppeteerOptions)) {
            mergeOptionsDefault.puppeteerOptions = Object.assign(Object.assign({}, interface_1.defaultConfig.puppeteerOptions), options.puppeteerOptions);
        }
        if (!!mergeOptionsDefault.session && mergeOptionsDefault.session.length) {
            const sessionName = mergeOptionsDefault.session;
            const replaceSession = sessionName.replace(/[^0-9a-zA-Zs]/g, '');
            if (replaceSession.length) {
                mergeOptionsDefault.session = replaceSession;
            }
            else {
                mergeOptionsDefault.session = interface_1.defaultConfig.session;
            }
        }
        if (mergeOptionsDefault.updatesLog) {
            await check_up_to_date_1.checkUpdates();
        }
        ev.statusFind = {
            erro: false,
            text: 'Starting browser...',
            status: 'initBrowser',
            statusFind: 'browser',
            onType: enum_1.onMode.connection,
            session: mergeOptionsDefault.session,
        };
        const wpage = await browser_1.initLaunch(mergeOptionsDefault, ev);
        if (typeof wpage !== 'boolean') {
            ev.statusFind = {
                erro: false,
                text: 'Opening whatsapp page!',
                status: 'initWhatsapp',
                statusFind: 'browser',
                onType: enum_1.onMode.connection,
                session: mergeOptionsDefault.session,
            };
            const page = await browser_1.initBrowser(wpage);
            if (typeof page !== 'boolean') {
                ev.statusFind = {
                    erro: false,
                    page: page,
                    statusFind: 'page',
                    onType: enum_1.onMode.connection,
                    session: mergeOptionsDefault.session,
                };
                await help_1.sleep(100);
                ev.statusFind = {
                    erro: false,
                    text: 'Website accessed successfully',
                    status: 'openedWhatsapp',
                    statusFind: 'browser',
                    onType: enum_1.onMode.connection,
                    session: mergeOptionsDefault.session,
                };
                const client = new webpack_1.webPack(page, wpage, mergeOptionsDefault, ev);
                help_1.checkingCloses(wpage, () => {
                    ev.statusFind = {
                        erro: true,
                        text: 'The browser has closed',
                        status: 'browserClosed',
                        statusFind: 'browser',
                        onType: enum_1.onMode.connection,
                        session: mergeOptionsDefault.session,
                    };
                }).catch(() => {
                    console.log('The client has been closed');
                });
                ev.on(enum_1.onMode.interfaceChange, async (interFace) => {
                    try {
                        client.cancelAutoClose();
                        if (interFace.result.mode === 'MAIN' &&
                            interFace.result.info === 'NORMAL') {
                            client.addChatWapi();
                            ev.statusFind = {
                                erro: false,
                                connect: true,
                                onType: enum_1.onMode.connection,
                                session: mergeOptionsDefault.session,
                                client: client,
                            };
                        }
                        if (interFace.result.mode === 'QR' &&
                            interFace.result.info === 'NORMAL') {
                            ev.statusFind = {
                                erro: false,
                                qrcode: interFace.result.info,
                                onType: enum_1.onMode.connection,
                                session: mergeOptionsDefault.session,
                            };
                            await client.qrCodeScan();
                        }
                    }
                    catch (_a) { }
                });
            }
            else {
                ev.statusFind = {
                    erro: true,
                    text: 'Error open whatzapp',
                    status: 'noOpenWhatzapp',
                    statusFind: 'browser',
                    onType: enum_1.onMode.connection,
                    session: mergeOptionsDefault.session,
                };
                wpage.close();
            }
        }
        else {
            ev.statusFind = {
                erro: true,
                text: 'Error open browser...',
                status: 'noOpenBrowser',
                statusFind: 'browser',
                onType: enum_1.onMode.connection,
                session: mergeOptionsDefault.session,
            };
        }
    });
}
exports.initServer = initServer;
//# sourceMappingURL=init.js.map